@@ -1,17 +1,18 @@
 module.exports = function (ws) {
     var add2 = function (req,res) {
         console.log("call meeee");
-        var x = req.params[0];
-        var y = req.params[1];
+        var x = req.params.x;
+        var y = req.params.y;
         console.log("add2() called with " + x + " and " + y);
-          req.r.table('apps')
+          //req.r.table('apps')
           //.getAll()
-          .run()
-          .then(function(data){
+          //.run()
+          //.then(function(data){
+            //  console.log(data);
               //console.log(JSON.stringify(data))
             //  return JSON.stringify(data);
-              res.json(data);
-          })
+              res.json({name:"ehllo"});
+          //});
        // return x + y;
     };
 
