@@ -1,19 +1,22 @@
 var config = {
 
-    host: "https://localhost:8080",
-    appId: "d8fcffc5-d1ab-40f1-ac63-d2643d7b9464",
-    appKey: "5fc02522e60958787b8298067513c5f4b44ca78a",
+    //host: "https://localhost:8080",
+    //appId: "d8fcffc5-d1ab-40f1-ac63-d2643d7b9464",
+   // appKey: "5fc02522e60958787b8298067513c5f4b44ca78a",
     database: {
-      host: 'rdb.codeunbug.com',
-      port: 28015
+      db:'test',
+      host: '127.0.0.1',
+      port: 28015,
+      // user:"admin",
+      // password:"next@2017"
     },
 
     ws:{
-       url: 'ws://128.199.230.199/ws',
+       url: 'ws://127.0.0.1:8000/ws',
        realm: 'realm1'
     },
 
-    oauth: {
+   /* oauth: {
       facebook: {
         provoider: 'facebook',
         clientId: '157316171444270',
@@ -26,27 +29,27 @@ var config = {
         clientSecret: '24WehldQ1ZPo2hXCXmxI_FFg',
         callbackURL: 'https://localhost:3000/oauth/google/callback'
       }
-    },
-    java: true,
+    },*/
+
     jdbc: [
       {
         name: "mysql",
         driver: "com.mysql.jdbc.Driver",
         url: "jdbc:mysql://db.codeunbug.com:3306/rmut_expert_db",
-        user: "root",
-        password: "ChangDao@2013"
+        user: "xx",
+        password: "xx"
       },
       {
         name: "mssql",
         driver: "com.microsoft.sqlserver.jdbc.SQLServerDriver",
-        url: "jdbc:sqlserver://10.3.231.39:1433;databaseName=EdiDb",
-        user: "edi",
-        password: "edi@2017"
+        url: "jdbc:sqlserver://xxx:1433;databaseName=xx",
+        user: "xx",
+        password: "xxx"
       },
       {
         name: "oracle",
         driver: "oracle.jdbc.OracleDriver",
-        url: "jdbc:oracle:thin:@25.32.200.27:1521:gl3d",
+        url: "jdbc:oracle:thin:@xx:1521:xx",
         user: "xx",
         password: "xx"
       }
