@@ -15,6 +15,13 @@ var logger = require('winston');
 var now = new Date();
 var logger_f="L"+now.getFullYear() + now.getMonth()+ now.getDate();
 const work_dir=process.cwd();
+const fs = require("fs");
+
+if (!fs.existsSync(work_dir+'/loggers/')) {
+    // Do something.
+    fs.mkdirSync(work_dir+'/loggers/', 0744);
+    
+}
 logger.configure({
     transports: [
       new (logger.transports.Console)(),
