@@ -52,21 +52,22 @@ exports.serve = function (nylon_path, port) {
 
         watcher.addWatcher(process.cwd() + '/app');
         watcher.addWatcher(process.cwd() + '/config');
-        watcher.addWatcher(process.cwd() + '/ssl');
+       // watcher.addWatcher(process.cwd() + '/ssl');
         watcher.addWatcher(nylon.nylon_path + '/java');
         watcher.addWatcher(nylon.nylon_path + '/lib');
 
     } else {
 
-        nylon.server_key = fs.readFileSync(nylon.work_dir + "/ssl/server.key");
-        nylon.server_cert = fs.readFileSync(nylon.work_dir + "/ssl/server.crt");
+      //  nylon.server_key = fs.readFileSync(nylon.work_dir + "/ssl/server.key");
+       // nylon.server_cert = fs.readFileSync(nylon.work_dir + "/ssl/server.crt");
 
-        nylon.req.SECRET_KEY=nylon.server_key;
+       // nylon.req.server_key=nylon.server_key;
+        nylon.server_key="1234560";
         var app = application(nylon);
         var server = null;
 
 
-        var options = {
+       /* var options = {
             key: nylon.server_key, //fs.readFileSync(work_dir + "/ssl/server.key"),
             cert: nylon.server_cert, // fs.readFileSync(work_dir + "/ssl/server.crt"),
             spdy: {
@@ -78,7 +79,7 @@ exports.serve = function (nylon_path, port) {
                     autoSpdy31: false
                 }
             }
-        };
+        };*/
 
 
      //    server = http2.createServer(options, app);
